@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
  *
  *     This program is free software; you can redistribute it
  *     and/or modify it under the terms of the GNU General Public
@@ -31,8 +31,6 @@
 #include <unistd.h>
 #include <errno.h>
 
-#include <iconv.h>
-
 #include "mutt.h"
 #include "charset.h"
 
@@ -288,7 +286,7 @@ iconv_t iconv_open (const char *tocode, const char *fromcode)
   return (iconv_t)(-1);
 }
 
-size_t iconv (iconv_t cd, const char **inbuf, size_t *inbytesleft,
+size_t iconv (iconv_t cd, ICONV_CONST char **inbuf, size_t *inbytesleft,
 	      char **outbuf, size_t *outbytesleft)
 {
   return 0;
@@ -316,8 +314,12 @@ iconv_t mutt_iconv_open (const char *tocode, const char *fromcode, int flags)
   iconv_t cd;
   
   mutt_canonical_charset (tocode1, sizeof (tocode1), tocode);
+
+#ifdef M_ICONV_HOOK_TO
+  /* Not used. */
   if ((flags & M_ICONV_HOOK_TO) && (tmp = mutt_charset_hook (tocode1)))
     mutt_canonical_charset (tocode1, sizeof (tocode1), tmp);
+#endif
 
   mutt_canonical_charset (fromcode1, sizeof (fromcode1), fromcode);
   if ((flags & M_ICONV_HOOK_FROM) && (tmp = mutt_charset_hook (fromcode1)))
@@ -338,12 +340,12 @@ iconv_t mutt_iconv_open (const char *tocode, const char *fromcode, int flags)
  * if you're supplying an outrepl, the target charset should be.
  */
 
-size_t mutt_iconv (iconv_t cd, const char **inbuf, size_t *inbytesleft,
+size_t mutt_iconv (iconv_t cd, ICONV_CONST char **inbuf, size_t *inbytesleft,
 		   char **outbuf, size_t *outbytesleft,
-		   const char **inrepls, const char *outrepl)
+		   ICONV_CONST char **inrepls, const char *outrepl)
 {
   size_t ret = 0, ret1;
-  const char *ib = *inbuf;
+  ICONV_CONST char *ib = *inbuf;
   size_t ibl = *inbytesleft;
   char *ob = *outbuf;
   size_t obl = *outbytesleft;
@@ -358,10 +360,10 @@ size_t mutt_iconv (iconv_t cd, const char **inbuf, size_t *inbytesleft,
       if (inrepls)
       {
 	/* Try replacing the input */
-	const char **t;
+	ICONV_CONST char **t;
 	for (t = inrepls; *t; t++)
 	{
-	  const char *ib1 = *t;
+	  ICONV_CONST char *ib1 = *t;
 	  size_t ibl1 = strlen (*t);
 	  char *ob1 = ob;
 	  size_t obl1 = obl;
@@ -406,7 +408,7 @@ size_t mutt_iconv (iconv_t cd, const char **inbuf, size_t *inbytesleft,
 int mutt_convert_string (char **ps, const char *from, const char *to, int flags)
 {
   iconv_t cd;
-  const char *repls[] = { "\357\277\275", "?", 0 };
+  ICONV_CONST char *repls[] = { "\357\277\275", "?", 0 };
   char *s = *ps;
 
   if (!s || !*s)
@@ -415,10 +417,10 @@ int mutt_convert_string (char **ps, const char *from, const char *to, int flags)
   if (to && from && (cd = mutt_iconv_open (to, from, flags)) != (iconv_t)-1)
   {
     int len;
-    const char *ib;
+    ICONV_CONST char *ib;
     char *buf, *ob;
     size_t ibl, obl;
-    const char **inrepls = 0;
+    ICONV_CONST char **inrepls = 0;
     char *outrepl = 0;
 
     if (mutt_is_utf8 (to))
@@ -438,7 +440,7 @@ int mutt_convert_string (char **ps, const char *from, const char *to, int flags)
 
     *ob = '\0';
 
-    safe_free ((void **) ps);
+    FREE (ps);
     *ps = buf;
     
     mutt_str_adjust (ps);
@@ -464,7 +466,7 @@ struct fgetconv_s
   char *ob;
   char *ib;
   size_t ibl;
-  const char **inrepls;
+  ICONV_CONST char **inrepls;
 };
 
 struct fgetconv_not
@@ -477,7 +479,7 @@ FGETCONV *fgetconv_open (FILE *file, const char *from, const char *to, int flags
 {
   struct fgetconv_s *fc;
   iconv_t cd = (iconv_t)-1;
-  static const char *repls[] = { "\357\277\275", "?", 0 };
+  static ICONV_CONST char *repls[] = { "\357\277\275", "?", 0 };
 
   if (from && to)
     cd = mutt_iconv_open (to, from, flags);
@@ -497,6 +499,27 @@ FGETCONV *fgetconv_open (FILE *file, const char *from, const char *to, int flags
   return (FGETCONV *)fc;
 }
 
+char *fgetconvs (char *buf, size_t l, FGETCONV *_fc)
+{
+  int c;
+  size_t r;
+  
+  for (r = 0; r + 1 < l;)
+  {
+    if ((c = fgetconv (_fc)) == EOF)
+      break;
+    buf[r++] = (char) c;
+    if (c == '\n') 
+      break;
+  }
+  buf[r] = '\0';
+  
+  if (r) 
+    return buf;
+  else 
+    return NULL;
+}
+
 int fgetconv (FGETCONV *_fc)
 {
   struct fgetconv_s *fc = (struct fgetconv_s *)_fc;
@@ -515,7 +538,7 @@ int fgetconv (FGETCONV *_fc)
   if (fc->ibl)
   {
     size_t obl = sizeof (fc->bufo);
-    iconv (fc->cd, (const char **)&fc->ib, &fc->ibl, &fc->ob, &obl);
+    iconv (fc->cd, (ICONV_CONST char **)&fc->ib, &fc->ibl, &fc->ob, &obl);
     if (fc->p < fc->ob)
       return (unsigned char)*(fc->p)++;
   }
@@ -539,7 +562,7 @@ int fgetconv (FGETCONV *_fc)
   if (fc->ibl)
   {
     size_t obl = sizeof (fc->bufo);
-    mutt_iconv (fc->cd, (const char **)&fc->ib, &fc->ibl, &fc->ob, &obl,
+    mutt_iconv (fc->cd, (ICONV_CONST char **)&fc->ib, &fc->ibl, &fc->ob, &obl,
 		fc->inrepls, 0);
     if (fc->p < fc->ob)
       return (unsigned char)*(fc->p)++;
@@ -556,5 +579,5 @@ void fgetconv_close (FGETCONV **_fc)
 
   if (fc->cd != (iconv_t)-1)
     iconv_close (fc->cd);
-  safe_free ((void **) _fc);
+  FREE (_fc);
 }
