@@ -280,7 +280,7 @@ void ci_bounce_message (HEADER *h, int *redraw)
   else
     strncat (prompt, "?", sizeof (prompt));
 
-  if (query_quadoption (OPT_BOUNCE, prompt) == M_NO)
+  if (query_quadoption (OPT_BOUNCE, prompt) != M_YES)
   {
     rfc822_free_address (&adr);
     CLEARLINE (LINES - 1);
@@ -761,7 +761,7 @@ int mutt_save_message (HEADER *h, int delete,
   mutt_expand_path (buf, sizeof (buf));
 
   /* check to make sure that this file is really the one the user wants */
-  if (!mutt_save_confirm (buf, &st))
+  if (mutt_save_confirm (buf, &st) != 0)
     return -1;
 
   if (WithCrypto && need_passphrase && (decode || decrypt)
@@ -803,7 +803,7 @@ int mutt_save_message (HEADER *h, int delete,
       }
     }
 
-    need_buffy_cleanup = (ctx.magic == M_MBOX || ctx.magic == M_MMDF || ctx.magic == M_KENDRA);
+    need_buffy_cleanup = (ctx.magic == M_MBOX || ctx.magic == M_MMDF);
 
     mx_close_mailbox (&ctx, NULL);
 
