@@ -150,7 +150,7 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
 	  headers[x] = this_one;
 	else 
 	{
-	  safe_realloc ((void **) &headers[x], mutt_strlen (headers[x]) + 
+	  safe_realloc (&headers[x], mutt_strlen (headers[x]) + 
 			mutt_strlen (this_one) + sizeof (char));
 	  strcat (headers[x], this_one); /* __STRCAT_CHECKED__ */
 	  FREE (&this_one);
@@ -217,7 +217,7 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
 	this_one = safe_strdup (buf);
       else
       {
-	safe_realloc ((void **) &this_one, 
+	safe_realloc (&this_one,
 		      mutt_strlen (this_one) + mutt_strlen (buf) + sizeof (char));
 	strcat (this_one, buf); /* __STRCAT_CHECKED__ */
       }
@@ -237,7 +237,7 @@ mutt_copy_hdr (FILE *in, FILE *out, long off_start, long off_end, int flags,
       headers[x] = this_one;
     else 
     {
-      safe_realloc ((void **) &headers[x], mutt_strlen (headers[x]) + 
+      safe_realloc (&headers[x], mutt_strlen (headers[x]) + 
 		    mutt_strlen (this_one) + sizeof (char));
       strcat (headers[x], this_one); /* __STRCAT_CHECKED__ */
       FREE (&this_one);
@@ -698,9 +698,9 @@ _mutt_append_message (CONTEXT *dest, FILE *fpin, CONTEXT *src, HEADER *hdr,
   MESSAGE *msg;
   int r;
 
-  if ((msg = mx_open_new_message (dest, hdr, (src->magic == M_MBOX || src->magic == M_MMDF || src->magic == M_KENDRA) ? 0 : M_ADD_FROM)) == NULL)
+  if ((msg = mx_open_new_message (dest, hdr, (src->magic == M_MBOX || src->magic == M_MMDF) ? 0 : M_ADD_FROM)) == NULL)
     return -1;
-  if (dest->magic == M_MBOX || dest->magic == M_MMDF || dest->magic == M_KENDRA)
+  if (dest->magic == M_MBOX || dest->magic == M_MMDF)
     chflags |= CH_FROM | CH_FORCE_FROM;
   chflags |= (dest->magic == M_MAILDIR ? CH_NOSTATUS : CH_UPDATE);
   r = _mutt_copy_message (msg->fp, fpin, hdr, body, flags, chflags);
@@ -795,7 +795,7 @@ static void format_address_header (char **h, ADDRESS *a)
   buflen  = linelen + 3;
   
   
-  safe_realloc ((void **) h, buflen);
+  safe_realloc (h, buflen);
   for (count = 0; a; a = a->next, count++)
   {
     ADDRESS *tmp = a->next;
@@ -827,7 +827,7 @@ static void format_address_header (char **h, ADDRESS *a)
     }
     
     buflen += l + mutt_strlen (cbuf) + mutt_strlen (c2buf);
-    safe_realloc ((void **) h, buflen);
+    safe_realloc (h, buflen);
     strcat (*h, cbuf);		/* __STRCAT_CHECKED__ */
     strcat (*h, buf);		/* __STRCAT_CHECKED__ */
     strcat (*h, c2buf);		/* __STRCAT_CHECKED__ */
@@ -844,7 +844,7 @@ static int address_header_decode (char **h)
 
   ADDRESS *a = NULL;
 
-  switch (tolower (*s))
+  switch (tolower ((unsigned char) *s))
   {
     case 'r': 
     {
