@@ -120,7 +120,7 @@ int crypt_valid_passphrase(int flags)
     if (pgp_use_gpg_agent())
     {
       *PgpPass = 0;
-      return 0; /* handled by gpg-agent */
+      return 1; /* handled by gpg-agent */
     }
 
     if (now < PgpExptime) return 1; /* just use the cached copy. */
@@ -766,7 +766,7 @@ static void crypt_fetch_signatures (BODY ***signatures, BODY *a, int *n)
     else
     {
       if((*n % 5) == 0)
-	safe_realloc ((void **) signatures, (*n + 6) * sizeof (BODY **));
+	safe_realloc (signatures, (*n + 6) * sizeof (BODY **));
 
       (*signatures)[(*n)++] = a;
     }
