@@ -39,7 +39,7 @@
  * is impossible to unget function keys in SLang, so roll our own input
  * buffering routines.
  */
-static size_t UngetCount = 0;
+size_t UngetCount = 0;
 static size_t UngetBufLen = 0;
 static event_t *KeyEvent;
 
@@ -62,7 +62,7 @@ event_t mutt_getch (void)
   int ch;
   event_t err = {-1, OP_NULL }, ret;
 
-  if (UngetCount)
+  if (!option(OPTUNBUFFEREDINPUT) && UngetCount)
     return (KeyEvent[--UngetCount]);
 
   SigInt = 0;
@@ -125,7 +125,9 @@ int mutt_get_password (char *msg, char *buf, size_t buflen)
   
   CLEARLINE (LINES-1);
   addstr (msg);
+  set_option (OPTUNBUFFEREDINPUT);
   rc = mutt_enter_string (buf, buflen, LINES - 1, mutt_strlen (msg), M_PASS);
+  unset_option (OPTUNBUFFEREDINPUT);
   CLEARLINE (LINES-1);
   return (rc);
 }
@@ -450,7 +452,7 @@ void mutt_ungetch (int ch, int op)
   tmp.op = op;
 
   if (UngetCount >= UngetBufLen)
-    safe_realloc ((void **) &KeyEvent, (UngetBufLen += 128) * sizeof(event_t));
+    safe_realloc (&KeyEvent, (UngetBufLen += 128) * sizeof(event_t));
 
   KeyEvent[UngetCount++] = tmp;
 }
