@@ -105,7 +105,7 @@ int imap_cmd_step (IMAP_DATA* idata)
   {
     if (len == cmd->blen)
     {
-      safe_realloc ((void**) &cmd->buf, cmd->blen + IMAP_CMD_BUFSIZE);
+      safe_realloc (&cmd->buf, cmd->blen + IMAP_CMD_BUFSIZE);
       cmd->blen = cmd->blen + IMAP_CMD_BUFSIZE;
       dprint (3, (debugfile, "imap_cmd_step: grew buffer to %u bytes\n",
 		  cmd->blen));
@@ -129,11 +129,13 @@ int imap_cmd_step (IMAP_DATA* idata)
   /* don't let one large string make cmd->buf hog memory forever */
   if ((cmd->blen > IMAP_CMD_BUFSIZE) && (len <= IMAP_CMD_BUFSIZE))
   {
-    safe_realloc ((void**) &cmd->buf, IMAP_CMD_BUFSIZE);
+    safe_realloc (&cmd->buf, IMAP_CMD_BUFSIZE);
     cmd->blen = IMAP_CMD_BUFSIZE;
     dprint (3, (debugfile, "imap_cmd_step: shrank buffer to %u bytes\n", cmd->blen));
   }
-  
+
+  idata->lastread = time(NULL);
+
   /* handle untagged messages. The caller still gets its shot afterwards. */
   if (!ascii_strncmp (cmd->buf, "* ", 2) &&
       cmd_handle_untagged (idata))
@@ -288,6 +290,11 @@ static void cmd_handle_fatal (IMAP_DATA* idata)
     mutt_error (_("Mailbox closed"));
     mutt_sleep (1);
     idata->state = IMAP_DISCONNECTED;
+  }
+
+  if (idata->state != IMAP_SELECTED)
+  {
+    idata->state = IMAP_DISCONNECTED;
     idata->status = 0;
   }
 }
@@ -301,7 +308,7 @@ static int cmd_handle_untagged (IMAP_DATA* idata)
 
   s = imap_next_word (idata->cmd.buf);
 
-  if ((idata->state == IMAP_SELECTED) && isdigit (*s))
+  if ((idata->state == IMAP_SELECTED) && isdigit ((unsigned char) *s))
   {
     pn = s;
     s = imap_next_word (s);
@@ -518,7 +525,7 @@ static void cmd_parse_myrights (IMAP_DATA* idata, char* s)
   /* zero out current rights set */
   memset (idata->rights, 0, sizeof (idata->rights));
 
-  while (*s && !isspace(*s))
+  while (*s && !isspace((unsigned char) *s))
   {
     switch (*s) 
     {
