@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 1996-9 Brandon Long <blong@fiction.net>
- * Copyright (C) 1999-2002 Brendan Cully <brendan@kublai.com>
+ * Copyright (C) 1999-2003 Brendan Cully <brendan@kublai.com>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -340,30 +340,48 @@ IMAP_DATA* imap_conn_find (const ACCOUNT* account, int flags)
 
   /* don't open a new connection if one isn't wanted */
   if (flags & M_IMAP_CONN_NONEW)
-    if (!idata || idata->state == IMAP_DISCONNECTED)
-      goto err_conn;
+  {
+    if (!idata)
+    {
+      mutt_socket_free (conn);
+      return NULL;
+    }
+    if (idata->state < IMAP_AUTHENTICATED)
+      return NULL;
+  }
   
   if (!idata)
   {
     /* The current connection is a new connection */
     if (! (idata = imap_new_idata ()))
-      goto err_conn;
+    {
+      mutt_socket_free (conn);
+      return NULL;
+    }
 
     conn->data = idata;
     idata->conn = conn;
   }
+
   if (idata->state == IMAP_DISCONNECTED)
-    if (imap_open_connection (idata) != 0)
-      goto err_idata;
+    imap_open_connection (idata);
+  if (idata->state == IMAP_CONNECTED)
+  {
+    if (!imap_authenticate (idata))
+    {
+      idata->state = IMAP_AUTHENTICATED;
+      if (idata->conn->ssf)
+	dprint (2, (debugfile, "Communication encrypted at %d bits\n",
+		    idata->conn->ssf));
+      imap_get_delim (idata);
+    }
+    else
+      mutt_account_unsetpass (&idata->conn->account);
+    
+    FREE (&idata->capstr);
+  }
   
   return idata;
-
- err_idata:
-  imap_free_idata (&idata);
- err_conn:
-  mutt_socket_free (conn);
-
-  return NULL;
 }
 
 int imap_open_connection (IMAP_DATA* idata)
@@ -375,8 +393,14 @@ int imap_open_connection (IMAP_DATA* idata)
 
   idata->state = IMAP_CONNECTED;
 
-  if (imap_cmd_step (idata) != IMAP_CMD_CONTINUE)
-    goto bail;
+  if (imap_cmd_step (idata) != IMAP_CMD_CONTINUE) {
+    mutt_error (_("Unexpected response received from server: %s"), idata->cmd.buf);
+    mutt_sleep (1);
+
+    mutt_socket_close (idata->conn);
+    idata->state = IMAP_DISCONNECTED;
+    return -1;
+  }
 
   if (ascii_strncasecmp ("* OK", idata->cmd.buf, 4) == 0)
   {
@@ -413,16 +437,13 @@ int imap_open_connection (IMAP_DATA* idata)
       }
     }
 #endif    
-    if (imap_authenticate (idata))
-      goto bail;
-    if (idata->conn->ssf)
-      dprint (2, (debugfile, "Communication encrypted at %d bits\n",
-	idata->conn->ssf));
   }
   else if (ascii_strncasecmp ("* PREAUTH", idata->cmd.buf, 9) == 0)
   {
+    idata->state = IMAP_AUTHENTICATED;
     if (imap_check_capabilities (idata) != 0)
       goto bail;
+    FREE (&idata->capstr);
   } 
   else
   {
@@ -430,17 +451,12 @@ int imap_open_connection (IMAP_DATA* idata)
     goto bail;
   }
 
-  FREE (&idata->capstr);
-  idata->state = IMAP_AUTHENTICATED;
-
-  imap_get_delim (idata);
   return 0;
 
  err_close_conn:
   mutt_socket_close (idata->conn);
  bail:
   FREE (&idata->capstr);
-  idata->state = IMAP_DISCONNECTED;
   return -1;
 }
 
@@ -520,14 +536,14 @@ int imap_open_mailbox (CONTEXT* ctx)
   /* we require a connection which isn't currently in IMAP_SELECTED state */
   if (!(idata = imap_conn_find (&(mx.account), M_IMAP_CONN_NOSELECT)))
     goto fail_noidata;
+  if (idata->state < IMAP_AUTHENTICATED)
+    goto fail;
+
   conn = idata->conn;
 
   /* once again the context is new */
   ctx->data = idata;
 
-  if (idata->status == IMAP_FATAL)
-    goto fail;
-
   /* Clean up path and replace the one in the ctx */
   imap_fix_path (idata, mx.mbox, buf, sizeof (buf));
   FREE(&(idata->mailbox));
@@ -665,8 +681,8 @@ int imap_open_mailbox (CONTEXT* ctx)
   }
 
   ctx->hdrmax = count;
-  ctx->hdrs = safe_malloc (count * sizeof (HEADER *));
-  ctx->v2r = safe_malloc (count * sizeof (int));
+  ctx->hdrs = safe_calloc (count, sizeof (HEADER *));
+  ctx->v2r = safe_calloc (count, sizeof (int));
   ctx->msgcount = 0;
   if (count && (imap_read_headers (idata, 0, count-1) < 0))
   {
@@ -680,7 +696,8 @@ int imap_open_mailbox (CONTEXT* ctx)
   return 0;
 
  fail:
-  idata->state = IMAP_AUTHENTICATED;
+  if (idata->state == IMAP_SELECTED)
+    idata->state = IMAP_AUTHENTICATED;
  fail_noidata:
   FREE (&mx.mbox);
   return -1;
@@ -706,7 +723,7 @@ int imap_open_mailbox_append (CONTEXT *ctx)
   conn = idata->conn;
 
   ctx->magic = M_IMAP;
-  ctx->data = (void *) idata;
+  ctx->data = idata;
 
   /* check mailbox existance */
 
@@ -917,7 +934,7 @@ int imap_sync_mailbox (CONTEXT* ctx, int expunge, int* index_hint)
    * to be changed. */
   imap_allow_reopen (ctx);
 
-  if ((rc = imap_check_mailbox (ctx, index_hint)) != 0)
+  if ((rc = imap_check_mailbox (ctx, index_hint, 0)) != 0)
     return rc;
 
   memset (&cmd, 0, sizeof (cmd));
@@ -1084,6 +1101,7 @@ void imap_close_mailbox (CONTEXT* ctx)
     idata->state = IMAP_AUTHENTICATED;
     FREE (&(idata->mailbox));
     mutt_free_list (&idata->flags);
+    idata->ctx = NULL;
   }
 
   /* free IMAP part of headers */
@@ -1108,25 +1126,18 @@ void imap_close_mailbox (CONTEXT* ctx)
  *	0		no change
  *	-1		error
  */
-int imap_check_mailbox (CONTEXT *ctx, int *index_hint)
+int imap_check_mailbox (CONTEXT *ctx, int *index_hint, int force)
 {
   /* overload keyboard timeout to avoid many mailbox checks in a row.
    * Most users don't like having to wait exactly when they press a key. */
-
   IMAP_DATA* idata;
-  time_t now;
   int result = 0;
 
   idata = (IMAP_DATA*) ctx->data;
 
-  now = time(NULL);
-  if (now > ImapLastCheck + Timeout)
-  {
-    ImapLastCheck = now;
-
-    if (imap_exec (idata, "NOOP", 0) != 0)
-      return -1;
-  }
+  if ((force || time(NULL) > idata->lastread + Timeout)
+      && imap_exec (idata, "NOOP", 0) != 0)
+    return -1;
 
   /* We call this even when we haven't run NOOP in case we have pending
    * changes to process, since we can reopen here. */
@@ -1223,7 +1234,7 @@ int imap_mailbox_check (char* path, int new)
       {
 	s = imap_next_word (s);
 	s = imap_next_word (s);
-	if (isdigit (*s))
+	if (isdigit ((unsigned char) *s))
 	{
 	  if (*s != '0')
 	  {
