@@ -124,7 +124,7 @@ static char *utf7_to_utf8 (const char *u7, size_t u7len, char **u8,
   if (u8len)
     *u8len = p - buf;
 
-  safe_realloc ((void **) &buf, p - buf);
+  safe_realloc (&buf, p - buf);
   if (u8)
     *u8 = buf;
   return buf;
@@ -238,7 +238,7 @@ static char *utf8_to_utf7 (const char *u8, size_t u8len, char **u7,
   *p++ = '\0';
   if (u7len)
     *u7len = p - buf;
-  safe_realloc ((void **) &buf, p - buf);
+  safe_realloc (&buf, p - buf);
   if (u7)  *u7 = buf;
   return buf;
 
