@@ -24,6 +24,8 @@
 #include "keymap.h"
 #include "mailbox.h"
 #include "url.h"
+#include "mutt_crypt.h"
+#include "mutt_idna.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -37,6 +39,10 @@
 #include <getopt.h>
 #endif
 
+#ifdef HAVE_LIBIDN
+#include <stringprep.h>
+#endif
+
 static const char *ReachingUs = N_("\
 To contact the developers, please mail to <mutt-dev@mutt.org>.\n\
 To report a bug, please use the flea(1) utility.\n");
@@ -147,6 +153,11 @@ static void show_version (void)
   printf (" [using libiconv %d.%d]", _LIBICONV_VERSION >> 8,
 	  _LIBICONV_VERSION & 0xff);
 #endif
+
+#ifdef HAVE_LIBIDN
+  printf (" [using libidn %s (compiled with %s)]", stringprep_check_version (NULL), 
+	  STRINGPREP_VERSION);
+#endif
   
   puts (_("\nCompile options:"));
 
@@ -299,23 +310,23 @@ static void show_version (void)
 #else
 	"-HAVE_RESIZETERM  "
 #endif
-	
-	
-	);
-  
+        );	
   
   puts (
-	
-#ifdef HAVE_PGP
-	"+HAVE_PGP  "
+#ifdef CRYPT_BACKEND_CLASSIC_PGP
+        "+CRYPT_BACKEND_CLASSIC_PGP  "
 #else
-	"-HAVE_PGP  "
+        "-CRYPT_BACKEND_CLASSIC_PGP  "
 #endif
-
-#ifdef HAVE_SMIME
-	"+HAVE_SMIME  "
+#ifdef CRYPT_BACKEND_CLASSIC_SMIME
+        "+CRYPT_BACKEND_CLASSIC_SMIME  "
 #else
-	"-HAVE_SMIME  "
+        "-CRYPT_BACKEND_CLASSIC_SMIME  "
+#endif
+#ifdef CRYPT_BACKEND_GPGME
+        "+CRYPT_BACKEND_GPGME  "
+#else
+        "-CRYPT_BACKEND_GPGME  "
 #endif
 
 #ifdef BUFFY_SIZE
@@ -382,6 +393,12 @@ static void show_version (void)
 	"-ICONV_NONTRANS  "
 #endif
 
+#if HAVE_LIBIDN
+	"+HAVE_LIBIDN  "
+#else
+	"-HAVE_LIBIDN  "
+#endif
+	
 #if HAVE_GETSID
 	"+HAVE_GETSID  "
 #else
@@ -646,7 +663,11 @@ int main (int argc, char **argv)
     for (; alias_queries; alias_queries = alias_queries->next)
     {
       if ((a = mutt_lookup_alias (alias_queries->data)))
-	mutt_write_address_list (a, stdout, 0);
+      {	
+	/* output in machine-readable form */
+	mutt_addrlist_to_idna (a, NULL);
+	mutt_write_address_list (a, stdout, 0, 0);
+      }
       else
       {
 	rv = 1;
@@ -683,7 +704,7 @@ int main (int argc, char **argv)
     if (stat (fpath, &sb) == -1 && errno == ENOENT)
     {
       snprintf (msg, sizeof (msg), _("%s does not exist. Create it?"), Maildir);
-      if (mutt_yesorno (msg, 1) == 1)
+      if (mutt_yesorno (msg, M_YES) == M_YES)
       {
 	if (mkdir (fpath, 0700) == -1 && errno != EEXIST)
 	  mutt_error ( _("Can't create %s: %s."), Maildir, strerror (errno));
