@@ -63,7 +63,8 @@ void mutt_set_charset (char *charset)
   if (!strcmp(buffer, "utf-8"))
     Charset_is_utf8 = 1;
 #ifndef HAVE_WC_FUNCS
-  else if (!strcmp(buffer, "euc-jp") || !strcmp(buffer, "shift_jis"))
+  else if (!strcmp(buffer, "euc-jp") || !strcmp(buffer, "shift_jis")
+  	|| !strcmp(buffer, "cp932"))
   {
     charset_is_ja = 1;
     charset_to_utf8 = iconv_open ("UTF-8", charset);
@@ -93,7 +94,7 @@ void mutt_set_charset (char *charset)
 static size_t wcrtomb_iconv (char *s, wchar_t wc, iconv_t cd)
 {
   char buf[MB_LEN_MAX];
-  const char *ib;
+  ICONV_CONST char *ib;
   char *ob;
   size_t ibl, obl, r;
 
@@ -144,7 +145,7 @@ size_t mbrtowc_iconv (wchar_t *pwc, const char *s, size_t n,
 		      mbstate_t *ps, iconv_t cd)
 {
   static mbstate_t mbstate;
-  const char *ib, *ibmax;
+  ICONV_CONST char *ib, *ibmax;
   char *ob, *t;
   size_t ibl, obl, k, r;
   char bufi[8], bufo[6];
