@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 1996-2002 Michael R. Elkins <me@mutt.org>
- * Copyright (C) 1999-2002 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1999-2002 Thomas Roessler <roessler@does-not-exist.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -70,8 +70,7 @@ static void mhs_alloc (struct mh_sequences *mhs, int i)
   if (i > mhs->max || !mhs->flags)
   {
     newmax = i + 128;
-    safe_realloc ((void **) &mhs->flags,
-		  sizeof (mhs->flags[0]) * (newmax + 1));
+    safe_realloc (&mhs->flags, sizeof (mhs->flags[0]) * (newmax + 1));
     for (j = mhs->max + 1; j <= newmax; j++)
       mhs->flags[j] = 0;
 
@@ -81,7 +80,7 @@ static void mhs_alloc (struct mh_sequences *mhs, int i)
 
 static void mhs_free_sequences (struct mh_sequences *mhs)
 {
-  safe_free ((void **) &mhs->flags);
+  FREE (&mhs->flags);
 }
 
 static short mhs_check (struct mh_sequences *mhs, int i)
@@ -164,7 +163,7 @@ static void mh_read_sequences (struct mh_sequences *mhs, const char *path)
     }
   }
 
-  safe_free ((void **) &buff);
+  FREE (&buff);
   safe_fclose (&fp);
 }
 
@@ -366,7 +365,7 @@ void mh_update_sequences (CONTEXT * ctx)
     unlink (tmpfname);
   }
 
-  safe_free ((void **) &tmpfname);
+  FREE (&tmpfname);
 }
 
 static void mh_sequences_add_one (CONTEXT * ctx, int n, short unseen,
@@ -423,7 +422,7 @@ static void mh_sequences_add_one (CONTEXT * ctx, int n, short unseen,
     }
   }
   safe_fclose (&ofp);
-  safe_free ((void **) &buff);
+  FREE (&buff);
 
   if (!unseen_done && unseen)
     fprintf (nfp, "%s: %d\n", NONULL (MhUnseen), n);
@@ -438,7 +437,7 @@ static void mh_sequences_add_one (CONTEXT * ctx, int n, short unseen,
   if (safe_rename (tmpfname, sequences) != 0)
     unlink (tmpfname);
 
-  safe_free ((void **) &tmpfname);
+  FREE (&tmpfname);
 }
 
 static void mh_update_maildir (struct maildir *md, struct mh_sequences *mhs)
@@ -470,11 +469,11 @@ static void maildir_free_entry (struct maildir **md)
   if (!md || !*md)
     return;
 
-  safe_free ((void **) &(*md)->canon_fname);
+  FREE (&(*md)->canon_fname);
   if ((*md)->h)
     mutt_free_header (&(*md)->h);
 
-  safe_free ((void **) md);
+  FREE (md);
 }
 
 static void maildir_free_maildir (struct maildir **md)
@@ -493,7 +492,7 @@ static void maildir_free_maildir (struct maildir **md)
 
 static void maildir_parse_flags (HEADER * h, const char *path)
 {
-  char *p;
+  char *p, *q = NULL;
 
   h->flagged = 0;
   h->read = 0;
@@ -502,6 +501,10 @@ static void maildir_parse_flags (HEADER * h, const char *path)
   if ((p = strrchr (path, ':')) != NULL && mutt_strncmp (p + 1, "2,", 2) == 0)
   {
     p += 3;
+    
+    mutt_str_replace (&h->maildir_flags, p);
+    q = h->maildir_flags;
+
     while (*p)
     {
       switch (*p)
@@ -525,10 +528,19 @@ static void maildir_parse_flags (HEADER * h, const char *path)
 	h->trash = 1;
 	h->deleted = 1;
 	break;
+      
+      default:
+	*q++ = *p;
+	break;
       }
       p++;
     }
   }
+  
+  if (q == h->maildir_flags)
+    FREE (&h->maildir_flags);
+  else if (q)
+    *q = '\0';
 }
 
 static void maildir_update_mtime (CONTEXT * ctx)
@@ -691,7 +703,7 @@ static int maildir_parse_dir (CONTEXT * ctx, struct maildir ***last,
   if (subdir)
   {
     snprintf (buf, sizeof (buf), "%s/%s", ctx->path, subdir);
-    is_old = (mutt_strcmp ("cur", subdir) == 0) && option (OPTMARKOLD);
+    is_old = (mutt_strcmp ("cur", subdir) == 0);
   }
   else
     strfcpy (buf, ctx->path, sizeof (buf));
@@ -851,6 +863,11 @@ int mh_open_new_message (MESSAGE * msg, CONTEXT * dest, HEADER * hdr)
   return mh_mkstemp (dest, &msg->fp, &msg->path);
 }
 
+int ch_compar (const void *a, const void *b)
+{
+  return (int)( *((const char *) a) - *((const char *) b));
+}
+
 static void maildir_flags (char *dest, size_t destlen, HEADER * hdr)
 {
   *dest = '\0';
@@ -863,13 +880,18 @@ static void maildir_flags (char *dest, size_t destlen, HEADER * hdr)
    * test even though there is no associated flag.
    */
   
-  if (hdr && (hdr->flagged || hdr->replied || hdr->read || hdr->deleted || hdr->old))
+  if (hdr && (hdr->flagged || hdr->replied || hdr->read || hdr->deleted || hdr->old || hdr->maildir_flags))
   {
-    snprintf (dest, destlen,
-	      ":2,%s%s%s%s",
+    char tmp[LONG_STRING];
+    snprintf (tmp, sizeof (tmp),
+	      "%s%s%s%s%s",
 	      hdr->flagged ? "F" : "",
 	      hdr->replied ? "R" : "",
-	      hdr->read ? "S" : "", hdr->deleted ? "T" : "");
+	      hdr->read ? "S" : "", hdr->deleted ? "T" : "",
+	      NONULL(hdr->maildir_flags));
+    if (hdr->maildir_flags)
+      qsort (tmp, strlen (tmp), 1, ch_compar);
+    snprintf (dest, destlen, ":2,%s", tmp);
   }
 }
 
@@ -1599,7 +1621,7 @@ int mh_check_mailbox (CONTEXT * ctx, int *index_hint)
       safe_fclose (&fp);
       if (safe_rename (tmp, buf) == -1)
 	unlink (tmp);
-      safe_free ((void **) &tmp);
+      FREE (&tmp);
     }
   }
 
