@@ -112,6 +112,9 @@
 #define M_TOKEN_COMMENT		(1<<5)	/* don't reap comments */
 #define M_TOKEN_SEMICOLON	(1<<6)	/* don't treat ; as special */
 
+/* flags for km_dokey() */
+#define M_KM_UNBUFFERED 1 /* don't read from the key buffer */
+
 typedef struct
 {
   char *data;	/* pointer to data */
@@ -261,35 +264,34 @@ enum
 /* quad-option vars */
 enum
 {
-
-  OPT_VERIFYSIG,      /* verify PGP signatures */
-  OPT_PGPTRADITIONAL, /* create old-style PGP messages */
-
-#ifdef USE_SSL
-  OPT_SSLSTARTTLS,
-#endif
-
-  OPT_PRINT,
-  OPT_INCLUDE,
+  OPT_ABORT,
+  OPT_BOUNCE,
+  OPT_COPY,
   OPT_DELETE,
+  OPT_FORWEDIT,
+  OPT_INCLUDE,
   OPT_MFUPTO,
   OPT_MIMEFWD,
+  OPT_MIMEFWDREST,
   OPT_MOVE,
-  OPT_COPY,
+  OPT_PGPTRADITIONAL, /* create old-style PGP messages */
 #ifdef USE_POP
   OPT_POPDELETE,
   OPT_POPRECONNECT,
 #endif
   OPT_POSTPONE,
+  OPT_PRINT,
   OPT_QUIT,
   OPT_REPLYTO,
-  OPT_ABORT,
   OPT_RECALL,
+#ifdef USE_SSL
+  OPT_SSLSTARTTLS,
+#endif
   OPT_SUBJECT,
-  OPT_MIMEFWDREST,
-  OPT_FORWEDIT,
-  OPT_MAX,
-  OPT_BOUNCE
+  OPT_VERIFYSIG,      /* verify PGP signatures */
+    
+  /* THIS MUST BE THE LAST VALUE. */
+  OPT_MAX
 };
 
 /* flags to ci_send_message() */
@@ -427,6 +429,8 @@ enum
   
   OPTCRYPTAUTOSIGN,
   OPTCRYPTAUTOENCRYPT,
+  OPTCRYPTAUTOPGP,
+  OPTCRYPTAUTOSMIME,
   OPTCRYPTREPLYENCRYPT,
   OPTCRYPTREPLYSIGN,
   OPTCRYPTREPLYSIGNENCRYPTED,
@@ -435,6 +439,7 @@ enum
   OPTASKCERTLABEL,
   OPTSDEFAULTDECRYPTKEY,
   OPTPGPIGNORESUB,
+  OPTPGPCHECKEXIT,
   OPTPGPLONGIDS,
   OPTPGPAUTOTRAD,
 #if 0
@@ -473,6 +478,7 @@ enum
   OPTREDRAWTREE,	/* (pseudo) redraw the thread tree */
   OPTPGPCHECKTRUST,	/* (pseudo) used by pgp_select_key () */
   OPTDONTHANDLEPGPKEYS,	/* (pseudo) used to extract PGP keys */
+  OPTUNBUFFEREDINPUT,   /* (pseudo) don't use key buffer */
 
   OPTMAX
 };
@@ -592,6 +598,8 @@ typedef struct body
   struct body *parts;           /* parts of a multipart or message/rfc822 */
   struct header *hdr;		/* header information for message/rfc822 */
 
+  struct attachptr *aptr;	/* Menu information, used in recvattach.c */
+  
   time_t stamp;			/* time stamp of last
 				 * encoding update.
 				 */
