@@ -284,7 +284,7 @@ static int ssl_socket_open (CONNECTION * conn)
 
   if (ssl_negotiate(data))
   {
-    ssl_socket_close (conn);
+    mutt_socket_close (conn);
     return -1;
   }
   
@@ -355,7 +355,7 @@ static int ssl_socket_close (CONNECTION * conn)
     X509_free (data->cert);
     SSL_free (data->ssl);
     SSL_CTX_free (data->ctx);
-    safe_free ((void **) &conn->sockdata);
+    FREE (&conn->sockdata);
   }
 
   return raw_socket_close (conn);
@@ -576,7 +576,8 @@ static int ssl_check_certificate (sslsockdata * data)
     menu->dialog[i] = (char *) safe_calloc (1, SHORT_STRING * sizeof (char));
 
   row = 0;
-  strfcpy (menu->dialog[row++], _("This certificate belongs to:"), SHORT_STRING);
+  strfcpy (menu->dialog[row], _("This certificate belongs to:"), SHORT_STRING);
+  row++;
   name = X509_NAME_oneline (X509_get_subject_name (data->cert),
 			    buf, sizeof (buf));
   for (i = 0; i < 5; i++)
@@ -586,7 +587,8 @@ static int ssl_check_certificate (sslsockdata * data)
   }
 
   row++;
-  strfcpy (menu->dialog[row++], _("This certificate was issued by:"), SHORT_STRING);
+  strfcpy (menu->dialog[row], _("This certificate was issued by:"), SHORT_STRING);
+  row++;
   name = X509_NAME_oneline (X509_get_issuer_name (data->cert),
 			    buf, sizeof (buf));
   for (i = 0; i < 5; i++)
@@ -627,6 +629,7 @@ static int ssl_check_certificate (sslsockdata * data)
   menu->help = helpstr;
 
   done = 0;
+  set_option(OPTUNBUFFEREDINPUT);
   while (!done)
   {
     switch (mutt_menuLoop (menu))
@@ -660,6 +663,7 @@ static int ssl_check_certificate (sslsockdata * data)
         break;
     }
   }
+  unset_option(OPTUNBUFFEREDINPUT);
   mutt_menuDestroy (&menu);
   return (done == 2);
 }
