@@ -521,7 +521,7 @@ char *mutt_gecos_name (char *dest, size_t destlen, struct passwd *pw)
       memmove (&dest[idx + pwnl], &dest[idx + 1],
 	       MAX(destlen - idx - pwnl - 1, 0));
       memcpy (&dest[idx], pw->pw_name, MIN(destlen - idx - 1, pwnl));
-      dest[idx] = toupper (dest[idx]);
+      dest[idx] = toupper ((unsigned char) dest[idx]);
     }
   }
       
@@ -766,66 +766,59 @@ void mutt_expand_file_fmt (char *dest, size_t destlen, const char *fmt, const ch
 
 void mutt_expand_fmt (char *dest, size_t destlen, const char *fmt, const char *src)
 {
-  const char *p = fmt;
-  const char *last = p;
-  size_t len;
+  const char *p;
+  char *d;
   size_t slen;
   int found = 0;
 
   slen = mutt_strlen (src);
+  destlen--;
   
-  while ((p = strchr (p, '%')) != NULL)
+  for (p = fmt, d = dest; destlen && *p; p++)
   {
-    if (p[1] == 's')
+    if (*p == '%') 
     {
-      found++;
-
-      len = (size_t) (p - last);
-      if (len)
+      switch (p[1])
       {
-	if (len > destlen - 1)
-	  len = destlen - 1;
-
-	memcpy (dest, last, len);
-	dest += len;
-	destlen -= len;
-
-	if (destlen <= 0)
-	{
-	  *dest = 0;
-	  break; /* no more space */
-	}
+	case '%':
+	  *d++ = *p++;
+	  destlen--;
+	  break;
+	case 's':
+	  found = 1;
+	  strfcpy (d, src, destlen + 1);
+	  d       += destlen > slen ? slen : destlen;
+	  destlen -= destlen > slen ? slen : destlen;
+	  p++;
+	  break;
+	default:
+	  *d++ = *p; 
+	  destlen--;
+	  break;
       }
-
-      strfcpy (dest, src, destlen);
-      if (slen > destlen)
-      {
-	/* no more room */
-	break;
-      }
-      dest += slen;
-      destlen -= slen;
-
-      p += 2;
-      last = p;
     }
-    else if (p[1] == '%')
-      p++;
-
-    p++;
+    else
+    {
+      *d++ = *p;
+      destlen--;
+    }
+  }
+  
+  *d = '\0';
+  
+  if (!found && destlen > 0)
+  {
+    strncat (dest, " ", destlen);
+    strncat (dest, src, destlen-1);
   }
-
-  if (found)
-    strfcpy (dest, last, destlen);
-  else
-    snprintf (dest, destlen, "%s %s", fmt, src);
   
 }
 
-/* return 0 on success, -1 on error */
+/* return 0 on success, -1 on abort, 1 on error */
 int mutt_check_overwrite (const char *attname, const char *path,
-				char *fname, size_t flen, int *append) 
+				char *fname, size_t flen, int *append, char **directory) 
 {
+  int rc = 0;
   char tmp[_POSIX_PATH_MAX];
   struct stat st;
 
@@ -836,18 +829,38 @@ int mutt_check_overwrite (const char *attname, const char *path,
     return -1;
   if (S_ISDIR (st.st_mode))
   {
-    if (mutt_yesorno (_("File is a directory, save under it?"), M_YES) != M_YES) 
-      return (-1);
+    if (directory)
+    {
+      switch (mutt_multi_choice
+	      (_("File is a directory, save under it? [(y)es, (n)o, (a)ll]"), _("yna")))
+      {
+	case 3:		/* all */
+	  mutt_str_replace (directory, fname);
+	  break;
+	case 1:		/* yes */
+	  FREE (directory);
+	  break;
+	case -1:	/* abort */
+	  FREE (directory); 
+	  return -1;
+	case  2:	/* no */
+	  FREE (directory);
+	  return 1;
+      }
+    }
+    else if ((rc = mutt_yesorno (_("File is a directory, save under it?"), M_YES)) != M_YES)
+      return (rc == M_NO) ? 1 : -1;
+
     if (!attname || !attname[0])
     {
       tmp[0] = 0;
       if (mutt_get_field (_("File under directory: "), tmp, sizeof (tmp),
 				      M_FILE | M_CLEAR) != 0 || !tmp[0])
 	return (-1);
-      snprintf (fname, flen, "%s/%s", path, tmp);
+      mutt_concat_path (fname, path, tmp, flen);
     }
     else
-      snprintf (fname, flen, "%s/%s", path, attname);
+      mutt_concat_path (fname, path, mutt_basename (attname), flen);
   }
   
   if (*append == 0 && access (fname, F_OK) == 0)
@@ -856,8 +869,9 @@ int mutt_check_overwrite (const char *attname, const char *path,
 	    (_("File exists, (o)verwrite, (a)ppend, or (c)ancel?"), _("oac")))
     {
       case -1: /* abort */
+        return -1;
       case 3:  /* cancel */
-	return -1;
+	return 1;
 
       case 2: /* append */
         *append = M_SAVE_APPEND;
@@ -1031,11 +1045,16 @@ void mutt_FormatString (char *dest,		/* output buffer */
       else
       {
 	short tolower =  0;
+	short nodots  = 0;
 	
-	if (ch == '_')
+	while (ch == '_' || ch == ':') 
 	{
+	  if (ch == '_')
+	    tolower = 1;
+	  else if (ch == ':') 
+	    nodots = 1;
+	  
 	  ch = *src++;
-	  tolower = 1;
 	}
 	
 	/* use callback function to handle this case */
@@ -1043,6 +1062,13 @@ void mutt_FormatString (char *dest,		/* output buffer */
 
 	if (tolower)
 	  mutt_strlower (buf);
+	if (nodots) 
+	{
+	  char *p = buf;
+	  for (; *p; p++)
+	    if (*p == '.')
+		*p = '_';
+	}
 	
 	if ((len = mutt_strlen (buf)) + wlen > destlen)
 	  len = (destlen - wlen > 0) ? (destlen - wlen) : 0;
@@ -1129,11 +1155,12 @@ FILE *mutt_open_read (const char *path, pid_t *thepid)
   return (f);
 }
 
-/* returns 1 if OK to proceed, 0 to abort */
+/* returns 0 if OK to proceed, -1 to abort, 1 to retry */
 int mutt_save_confirm (const char *s, struct stat *st)
 {
   char tmp[_POSIX_PATH_MAX];
-  int ret = 1;
+  int ret = 0;
+  int rc;
   int magic = 0;
 
   magic = mx_get_magic (s);
@@ -1142,7 +1169,7 @@ int mutt_save_confirm (const char *s, struct stat *st)
   if (magic == M_POP)
   {
     mutt_error _("Can't save message to POP mailbox.");
-    return 0;
+    return 1;
   }
 #endif
 
@@ -1151,14 +1178,16 @@ int mutt_save_confirm (const char *s, struct stat *st)
     if (magic == -1)
     {
       mutt_error (_("%s is not a mailbox!"), s);
-      return 0;
+      return 1;
     }
 
     if (option (OPTCONFIRMAPPEND))
     {
       snprintf (tmp, sizeof (tmp), _("Append messages to %s?"), s);
-      if (mutt_yesorno (tmp, M_YES) != M_YES)
-	ret = 0;
+      if ((rc = mutt_yesorno (tmp, M_YES)) == M_NO)
+	ret = 1;
+      else if (rc == -1)
+	ret = -1;
     }
   }
   else
@@ -1175,14 +1204,16 @@ int mutt_save_confirm (const char *s, struct stat *st)
 	if (option (OPTCONFIRMCREATE))
 	{
 	  snprintf (tmp, sizeof (tmp), _("Create %s?"), s);
-	  if (mutt_yesorno (tmp, M_YES) != M_YES)
-	    ret = 0;
+	  if ((rc = mutt_yesorno (tmp, M_YES)) == M_NO)
+	    ret = 1;
+	  else if (rc == -1)
+	    ret = -1;
 	}
       }
       else
       {
 	mutt_perror (s);
-	return 0;
+	return 1;
       }
     }
   }
@@ -1226,12 +1257,12 @@ void state_mark_attach (STATE *s)
 
 void state_attach_puts (const char *t, STATE *s)
 {
-  state_mark_attach (s);
+  if (*t != '\n') state_mark_attach (s);
   while (*t)
   {
     state_putc (*t, s);
     if (*t++ == '\n' && *t)
-      state_mark_attach (s);
+      if (*t != '\n') state_mark_attach (s);
   }
 }
 
