@@ -466,8 +466,6 @@ int mx_set_magic (const char *s)
     DefaultMagic = M_MH;
   else if (ascii_strcasecmp (s, "maildir") == 0)
     DefaultMagic = M_MAILDIR;
-  else if (ascii_strcasecmp (s, "kendra") == 0)
-    DefaultMagic = M_KENDRA;
   else
     return (-1);
 
@@ -1360,7 +1358,7 @@ int mx_check_mailbox (CONTEXT *ctx, int *index_hint, int lock)
 
 #ifdef USE_IMAP
       case M_IMAP:
-	return (imap_check_mailbox (ctx, index_hint));
+	return (imap_check_mailbox (ctx, index_hint, 0));
 #endif /* USE_IMAP */
 
 #ifdef USE_POP
@@ -1464,13 +1462,6 @@ int mx_commit_message (MESSAGE *msg, CONTEXT *ctx)
       break;
     }
 
-    case M_KENDRA:
-    {
-      if (fputs (KENDRA_SEP, msg->fp) == EOF)
-	r = -1;
-      break;
-    }
-
 #ifdef USE_IMAP
     case M_IMAP:
     {
@@ -1493,7 +1484,7 @@ int mx_commit_message (MESSAGE *msg, CONTEXT *ctx)
     }
   }
   
-  if (r == 0 && (ctx->magic == M_MBOX || ctx->magic == M_MMDF || ctx->magic == M_KENDRA)
+  if (r == 0 && (ctx->magic == M_MBOX || ctx->magic == M_MMDF)
       && (fflush (msg->fp) == EOF || fsync (fileno (msg->fp)) == -1))
   {
     mutt_perror _("Can't write message");
@@ -1537,16 +1528,24 @@ int mx_close_message (MESSAGE **msg)
 void mx_alloc_memory (CONTEXT *ctx)
 {
   int i;
-
+  size_t s = MAX (sizeof (HEADER *), sizeof (int));
+  
+  if ((ctx->hdrmax + 25) * s < ctx->hdrmax * s)
+  {
+    mutt_error _("Integer overflow -- can't allocate memory.");
+    sleep (1);
+    mutt_exit (1);
+  }
+  
   if (ctx->hdrs)
   {
-    safe_realloc ((void **) &ctx->hdrs, sizeof (HEADER *) * (ctx->hdrmax += 25));
-    safe_realloc ((void **) &ctx->v2r, sizeof (int) * ctx->hdrmax);
+    safe_realloc (&ctx->hdrs, sizeof (HEADER *) * (ctx->hdrmax += 25));
+    safe_realloc (&ctx->v2r, sizeof (int) * ctx->hdrmax);
   }
   else
   {
-    ctx->hdrs = safe_malloc (sizeof (HEADER *) * (ctx->hdrmax += 25));
-    ctx->v2r = safe_malloc (sizeof (int) * ctx->hdrmax);
+    ctx->hdrs = safe_calloc ((ctx->hdrmax += 25), sizeof (HEADER *));
+    ctx->v2r = safe_calloc (ctx->hdrmax, sizeof (int));
   }
   for (i = ctx->msgcount ; i < ctx->hdrmax ; i++)
   {
@@ -1636,7 +1635,6 @@ int mx_check_empty (const char *path)
   {
     case M_MBOX:
     case M_MMDF:
-    case M_KENDRA:
       return mbox_check_empty (path);
     case M_MH:
       return mh_check_empty (path);
