@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -292,8 +292,8 @@ static int rfc1524_mailcap_parse (BODY *a,
 	      && test_command)
 	  {
 	    len = mutt_strlen (test_command) + STRING;
-	    safe_realloc ((void **) &test_command, len);
-	    rfc1524_expand_command (a, NULL, type, test_command, len);
+	    safe_realloc (&test_command, len);
+	    rfc1524_expand_command (a, a->filename, type, test_command, len);
 	    if (mutt_system (test_command))
 	    {
 	      /* a non-zero exit code means test failed */
@@ -330,13 +330,13 @@ static int rfc1524_mailcap_parse (BODY *a,
 	/* reset */
 	if (entry)
 	{
-	  safe_free ((void **) &entry->command);
-	  safe_free ((void **) &entry->composecommand);
-	  safe_free ((void **) &entry->composetypecommand);
-	  safe_free ((void **) &entry->editcommand);
-	  safe_free ((void **) &entry->printcommand);
-	  safe_free ((void **) &entry->nametemplate);
-	  safe_free ((void **) &entry->convert);
+	  FREE (&entry->command);
+	  FREE (&entry->composecommand);
+	  FREE (&entry->composetypecommand);
+	  FREE (&entry->editcommand);
+	  FREE (&entry->printcommand);
+	  FREE (&entry->nametemplate);
+	  FREE (&entry->convert);
 	  entry->needsterminal = 0;
 	  entry->copiousoutput = 0;
 	}
@@ -344,7 +344,7 @@ static int rfc1524_mailcap_parse (BODY *a,
     } /* while (!found && (buf = mutt_read_line ())) */
     fclose (fp);
   } /* if ((fp = fopen ())) */
-  safe_free ((void **) &buf);
+  FREE (&buf);
   return found;
 }
 
@@ -357,14 +357,14 @@ void rfc1524_free_entry(rfc1524_entry **entry)
 {
   rfc1524_entry *p = *entry;
 
-  safe_free((void **)&p->command);
-  safe_free((void **)&p->testcommand);
-  safe_free((void **)&p->composecommand);
-  safe_free((void **)&p->composetypecommand);
-  safe_free((void **)&p->editcommand);
-  safe_free((void **)&p->printcommand);
-  safe_free((void **)&p->nametemplate);
-  safe_free((void **)entry);
+  FREE (&p->command);
+  FREE (&p->testcommand);
+  FREE (&p->composecommand);
+  FREE (&p->composetypecommand);
+  FREE (&p->editcommand);
+  FREE (&p->printcommand);
+  FREE (&p->nametemplate);
+  FREE (entry);
 }
 
 /*
@@ -392,6 +392,8 @@ int rfc1524_mailcap_lookup (BODY *a, char *type, rfc1524_entry *entry, int opt)
     return 0;
   }
 
+  mutt_check_lookup_list (a, type, SHORT_STRING);
+
   while (!found && *curr)
   {
     x = 0;
