@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
 #include "mutt.h"
@@ -154,7 +154,7 @@ int mutt_parse_unscore (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 	last = tmp;
 	tmp = tmp->next;
 	mutt_pattern_free (&last->pat);
-	safe_free ((void **) &last);
+	FREE (&last);
       }
       Score = NULL;
     }
@@ -169,7 +169,7 @@ int mutt_parse_unscore (BUFFER *buf, BUFFER *s, unsigned long data, BUFFER *err)
 	  else
 	    Score = tmp->next;
 	  mutt_pattern_free (&tmp->pat);
-	  safe_free ((void **) &tmp);
+	  FREE (&tmp);
 	  /* there should only be one score per pattern, so we can stop here */
 	  break;
 	}
