@@ -379,7 +379,7 @@ char* smime_ask_for_key (char *prompt, char *mailbox, short public)
     }
     /* Read Entries */
     cur = 0;
-    Table = safe_malloc(sizeof (smime_id) * cert_num);
+    Table = safe_calloc(cert_num, sizeof (smime_id));
     while (!feof(index)) {
         numFields = fscanf (index, MUTT_FORMAT(STRING) " %x.%i " MUTT_FORMAT(STRING), fields[0], &hash,
           &hash_suffix, fields[2]);
@@ -792,7 +792,7 @@ char *smime_findKeys (ADDRESS *to, ADDRESS *cc, ADDRESS *bcc)
     }
     
     keylist_size += mutt_strlen (keyID) + 1;
-    safe_realloc ((void **)&keylist, keylist_size);
+    safe_realloc (&keylist, keylist_size);
     sprintf (keylist + keylist_used, "%s", keyID);	/* __SPRINTF_CHECKED__ */
     keylist_used = mutt_strlen (keylist);
 
@@ -1160,7 +1160,7 @@ int smime_verify_sender(HEADER *h)
   if(h->security & ENCRYPT)
     mutt_copy_message (fpout, Context, h,
 		       M_CM_DECODE_CRYPT & M_CM_DECODE_SMIME,
-		       CH_WEED|CH_NONEWLINE);
+		       CH_MIME|CH_WEED|CH_NONEWLINE);
   else
     mutt_copy_message (fpout, Context, h, 0, 0);
 
@@ -1323,7 +1323,7 @@ BODY *smime_build_smime_entity (BODY *a, char *certlist)
   rewind (fpout);
   empty = (fgetc (fpout) == EOF);
   fclose (fpout);
-
+ 
   fflush (smimeerr);
   rewind (smimeerr);
   while (fgets (buf, sizeof (buf) - 1, smimeerr) != NULL)
