@@ -591,7 +591,7 @@ THREAD *mutt_sort_subthreads (THREAD *thread, int init)
 
   top = thread;
 
-  array = safe_malloc ((array_size = 256) * sizeof (THREAD *));
+  array = safe_calloc ((array_size = 256), sizeof (THREAD *));
   while (1)
   {
     if (init || !thread->sort_key)
@@ -630,8 +630,7 @@ THREAD *mutt_sort_subthreads (THREAD *thread, int init)
 	for (i = 0; thread; i++, thread = thread->prev)
 	{
 	  if (i >= array_size)
-	    safe_realloc ((void **) &array,
-			  (array_size *= 2) * sizeof (THREAD *));
+	    safe_realloc (&array, (array_size *= 2) * sizeof (THREAD *));
 
 	  array[i] = thread;
 	}
@@ -1272,7 +1271,7 @@ int mutt_messages_in_thread (CONTEXT *ctx, HEADER *hdr, int flag)
   THREAD *threads[2];
   int i, rc;
 
-  if ((Sort & SORT_MASK) != SORT_THREADS)
+  if ((Sort & SORT_MASK) != SORT_THREADS || !hdr->thread)
     return (1);
 
   threads[0] = hdr->thread;
